# Dora Dagster

Integration of [Dora](https://pypi.org/project/dora-core/) with [Dagster](https://dagster.io/) for data pipelines and orquestration.

---

[Dora Project](https://github.com/doraproject) is a recent open-source project based on technology developed at [Compasso UOL](https://compassouol.com/)
